==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/ComponentOverrideBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ComponentOverrideBuilder extends io.fabric8.openshift.api.model.ComponentOverrideFluentImpl<io.fabric8.openshift.api.model.ComponentOverrideBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ComponentOverride,io.fabric8.openshift.api.model.ComponentOverrideBuilder>{
  public ComponentOverrideBuilder() {
    this(false);
  }
  public ComponentOverrideBuilder(java.lang.Boolean validationEnabled) {
    this(new ComponentOverride(), validationEnabled);
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverrideFluent<?> fluent) {
    this(fluent, false);
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverrideFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ComponentOverride(), validationEnabled);
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverrideFluent<?> fluent,io.fabric8.openshift.api.model.ComponentOverride instance) {
    this(fluent, instance, false);
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverrideFluent<?> fluent,io.fabric8.openshift.api.model.ComponentOverride instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroup(instance.getGroup()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withUnmanaged(instance.getUnmanaged()); 
    this.validationEnabled = validationEnabled; 
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverride instance) {
    this(instance,false);
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverride instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroup(instance.getGroup()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withUnmanaged(instance.getUnmanaged()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ComponentOverrideFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ComponentOverride build() {
    ComponentOverride buildable = new ComponentOverride(fluent.getGroup(),fluent.getKind(),fluent.getName(),fluent.getNamespace(),fluent.getUnmanaged());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ComponentOverrideBuilder that = (ComponentOverrideBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ComponentOverrideBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ComponentOverrideBuilder extends io.fabric8.openshift.api.model.ComponentOverrideFluentImpl<io.fabric8.openshift.api.model.ComponentOverrideBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ComponentOverride,io.fabric8.openshift.api.model.ComponentOverrideBuilder>{
  public ComponentOverrideBuilder() {
    this(false);
  }
  public ComponentOverrideBuilder(java.lang.Boolean validationEnabled) {
    this(new ComponentOverride(), validationEnabled);
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverrideFluent<?> fluent) {
    this(fluent, false);
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverrideFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ComponentOverride(), validationEnabled);
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverrideFluent<?> fluent,io.fabric8.openshift.api.model.ComponentOverride instance) {
    this(fluent, instance, false);
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverrideFluent<?> fluent,io.fabric8.openshift.api.model.ComponentOverride instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroup(instance.getGroup()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withUnmanaged(instance.getUnmanaged()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverride instance) {
    this(instance,false);
  }
  public ComponentOverrideBuilder(io.fabric8.openshift.api.model.ComponentOverride instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroup(instance.getGroup()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withUnmanaged(instance.getUnmanaged()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ComponentOverrideFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ComponentOverride build() {
    ComponentOverride buildable = new ComponentOverride(fluent.getGroup(),fluent.getKind(),fluent.getName(),fluent.getNamespace(),fluent.getUnmanaged());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ComponentOverrideBuilder that = (ComponentOverrideBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
